Class: Net::IMAP::AppendUIDData
- Inherits:
-
Object
- Object
- Net::IMAP::AppendUIDData
- Defined in:
- lib/net/imap/uidplus_data.rb
Overview
NOTE: AppendUIDData replaced UIDPlusData for
APPENDUIDin the0.6.0release. To use AppendUIDData before0.6.0, set Config#parser_use_deprecated_uidplus_data tofalse.
AppendUIDData represents the ResponseCode#data that accompanies the APPENDUID response code.
A server that supports UIDPLUS (or IMAP4rev2) should send AppendUIDData inside every TaggedResponse returned by the append command—unless the target mailbox reports UIDNOTSTICKY.
Required capability
Requires either UIDPLUS [RFC4315] or IMAP4rev2 capability.
Instance Method Summary collapse
-
#initialize(uidvalidity:, assigned_uids:) ⇒ AppendUIDData
constructor
A new instance of AppendUIDData.
-
#size ⇒ Object
Returns the number of messages that have been appended.
Constructor Details
#initialize(uidvalidity:, assigned_uids:) ⇒ AppendUIDData
Returns a new instance of AppendUIDData.
23 24 25 26 27 28 29 30 31 |
# File 'lib/net/imap/uidplus_data.rb', line 23 def initialize(uidvalidity:, assigned_uids:) uidvalidity = Integer(uidvalidity) assigned_uids = SequenceSet[assigned_uids] NumValidator.ensure_nz_number(uidvalidity) if assigned_uids.include_star? raise DataFormatError, "uid-set cannot contain '*'" end super end |
Instance Method Details
#size ⇒ Object
Returns the number of messages that have been appended.
45 46 47 |
# File 'lib/net/imap/uidplus_data.rb', line 45 def size assigned_uids.count_with_duplicates end |