Class: Net::IMAP::BodyTypeMultipart
- Inherits:
-
Struct
- Object
- Struct
- Net::IMAP::BodyTypeMultipart
- Includes:
- BodyStructure
- Defined in:
- lib/net/imap/response_data.rb
Overview
Net::IMAP::BodyTypeMultipart represents body structures of messages and message parts, when Content-Type is multipart/*.
Instance Attribute Summary collapse
-
#disposition ⇒ Object
Returns the value of attribute disposition.
-
#extension ⇒ Object
Returns the value of attribute extension.
-
#language ⇒ Object
Returns the value of attribute language.
-
#location ⇒ Object
Returns the value of attribute location.
-
#media_type ⇒ Object
Returns the value of attribute media_type.
-
#param ⇒ Object
Returns the value of attribute param.
-
#parts ⇒ Object
Returns the value of attribute parts.
-
#subtype ⇒ Object
Returns the value of attribute subtype.
Instance Method Summary collapse
-
#media_subtype ⇒ Object
Obsolete: use
subtypeinstead. -
#multipart? ⇒ Boolean
:call-seq: multipart? -> true.
Instance Attribute Details
#disposition ⇒ Object
Returns the value of attribute disposition
1019 1020 1021 |
# File 'lib/net/imap/response_data.rb', line 1019 def disposition @disposition end |
#extension ⇒ Object
Returns the value of attribute extension
1019 1020 1021 |
# File 'lib/net/imap/response_data.rb', line 1019 def extension @extension end |
#language ⇒ Object
Returns the value of attribute language
1019 1020 1021 |
# File 'lib/net/imap/response_data.rb', line 1019 def language @language end |
#location ⇒ Object
Returns the value of attribute location
1019 1020 1021 |
# File 'lib/net/imap/response_data.rb', line 1019 def location @location end |
#media_type ⇒ Object
Returns the value of attribute media_type
1019 1020 1021 |
# File 'lib/net/imap/response_data.rb', line 1019 def media_type @media_type end |
#param ⇒ Object
Returns the value of attribute param
1019 1020 1021 |
# File 'lib/net/imap/response_data.rb', line 1019 def param @param end |
#parts ⇒ Object
Returns the value of attribute parts
1019 1020 1021 |
# File 'lib/net/imap/response_data.rb', line 1019 def parts @parts end |
#subtype ⇒ Object
Returns the value of attribute subtype
1019 1020 1021 |
# File 'lib/net/imap/response_data.rb', line 1019 def subtype @subtype end |
Instance Method Details
#media_subtype ⇒ Object
Obsolete: use subtype instead. Calling this will generate a warning message to stderr, then return the value of subtype.
1087 1088 1089 1090 1091 |
# File 'lib/net/imap/response_data.rb', line 1087 def media_subtype warn("media_subtype is obsolete, use subtype instead.\n", uplevel: 1, category: :deprecated) return subtype end |
#multipart? ⇒ Boolean
:call-seq: multipart? -> true
BodyTypeMultipart is used for multipart MIME parts.
1079 1080 1081 |
# File 'lib/net/imap/response_data.rb', line 1079 def multipart? return true end |