Class: Net::IMAP::RawText

Inherits:
ValidNonLiteralData show all
Defined in:
lib/net/imap/command_data.rb

Overview

Represents IMAP text data, which covers everything in the IMAP grammar, except for literal, literal8, and the concluding CRLF.

NOTE: The current implementation does not verify that the connection supports UTF-8. Future versions may validate this.

Method Summary

Methods inherited from ValidNonLiteralData

#ascii_only?, #initialize, #send_data, #validate

Methods inherited from CommandData

#send_data, validate, #validate

Constructor Details

This class inherits a constructor from Net::IMAP::ValidNonLiteralData