Class: Net::IMAP::TaggedResponse
- Inherits:
-
Struct
- Object
- Struct
- Net::IMAP::TaggedResponse
- Defined in:
- lib/net/imap/response_data.rb
Overview
Net::IMAP::TaggedResponse represents tagged responses.
The server completion result response indicates the success or failure of the operation. It is tagged with the same tag as the client command which began the operation.
Instance Attribute Summary collapse
-
#data ⇒ Object
Returns the value of attribute data.
-
#name ⇒ Object
Returns the value of attribute name.
-
#raw_data ⇒ Object
Returns the value of attribute raw_data.
-
#tag ⇒ Object
Returns the value of attribute tag.
Instance Attribute Details
#data ⇒ Object
Returns the value of attribute data
138 139 140 |
# File 'lib/net/imap/response_data.rb', line 138 def data @data end |
#name ⇒ Object
Returns the value of attribute name
138 139 140 |
# File 'lib/net/imap/response_data.rb', line 138 def name @name end |
#raw_data ⇒ Object
Returns the value of attribute raw_data
138 139 140 |
# File 'lib/net/imap/response_data.rb', line 138 def raw_data @raw_data end |
#tag ⇒ Object
Returns the value of attribute tag
138 139 140 |
# File 'lib/net/imap/response_data.rb', line 138 def tag @tag end |