Class: Net::IMAP::UnparsedData

Inherits:
Struct
  • Object
show all
Defined in:
lib/net/imap/response_data.rb

Overview

Note: This represents an intentionally unstable API. Where instances of this class are returned, future releases may return a different (incompatible) object without deprecation or warning.

Net::IMAP::UnparsedData represents data for unknown response types or unknown extensions to response types without a well-defined extension grammar. UnparsedData represents the portion of the response which the parser has skipped over, without attempting to parse it.

parser = Net::IMAP::ResponseParser.new
response = parser.parse "* X-UNKNOWN-TYPE can't parse this\r\n"
response => Net::IMAP::UntaggedResponse(
  name: "X-UNKNOWN-TYPE",
  data: Net::IMAP::UnparsedData(unparsed_data: "can't parse this"),
)

See also: UnparsedNumericResponseData, ExtensionData, IgnoredResponse, InvalidParseData.

Instance Attribute Summary collapse

Instance Attribute Details

#unparsed_dataObject

Returns the value of attribute unparsed_data

Returns:

  • (Object)

    the current value of unparsed_data



90
91
92
# File 'lib/net/imap/response_data.rb', line 90

def unparsed_data
  @unparsed_data
end