Class: Net::IMAP::UnparsedNumericResponseData
- Inherits:
-
Struct
- Object
- Struct
- Net::IMAP::UnparsedNumericResponseData
- Defined in:
- lib/net/imap/response_data.rb
Overview
Note: This represents an intentionally unstable API. Where instances of this class are returned, future releases may return a different (incompatible) object without deprecation or warning.
Net::IMAP::UnparsedNumericResponseData represents data for unhandled response types with a numeric prefix. See the documentation for #number.
parser = Net::IMAP::ResponseParser.new
response = parser.parse "* 123 X-UNKNOWN-TYPE can't parse this\r\n"
response => Net::IMAP::UntaggedResponse(
name: "X-UNKNOWN-TYPE",
data: Net::IMAP::UnparsedNumericData(
number: 123,
unparsed_data: "can't parse this"
),
)
See also: UnparsedData, ExtensionData, IgnoredResponse, InvalidParseData
Instance Attribute Summary collapse
-
#number ⇒ Object
Returns the value of attribute number.
-
#unparsed_data ⇒ Object
Returns the value of attribute unparsed_data.
Instance Attribute Details
#number ⇒ Object
Returns the value of attribute number
171 172 173 |
# File 'lib/net/imap/response_data.rb', line 171 def number @number end |
#unparsed_data ⇒ Object
Returns the value of attribute unparsed_data
171 172 173 |
# File 'lib/net/imap/response_data.rb', line 171 def unparsed_data @unparsed_data end |