Class: Net::IMAP::BodyTypeMessage
- Inherits:
-
Struct
- Object
- Struct
- Net::IMAP::BodyTypeMessage
- Includes:
- BodyStructure
- Defined in:
- lib/net/imap/response_data.rb
Overview
Net::IMAP::BodyTypeMessage represents the body structures of messages and message parts, when Content-Type is message/rfc822 or message/global.
BodyTypeMessage contains all of the fields of BodyTypeBasic. See BodyTypeBasic for documentation of the following fields:
Instance Attribute Summary collapse
-
#body ⇒ Object
Returns the value of attribute body.
-
#content_id ⇒ Object
Returns the value of attribute content_id.
-
#description ⇒ Object
Returns the value of attribute description.
-
#disposition ⇒ Object
Returns the value of attribute disposition.
-
#encoding ⇒ Object
Returns the value of attribute encoding.
-
#envelope ⇒ Object
Returns the value of attribute envelope.
-
#extension ⇒ Object
Returns the value of attribute extension.
-
#language ⇒ Object
Returns the value of attribute language.
-
#lines ⇒ Object
Returns the value of attribute lines.
-
#location ⇒ Object
Returns the value of attribute location.
-
#md5 ⇒ Object
Returns the value of attribute md5.
-
#media_type ⇒ Object
Returns the value of attribute media_type.
-
#param ⇒ Object
Returns the value of attribute param.
-
#size ⇒ Object
Returns the value of attribute size.
-
#subtype ⇒ Object
Returns the value of attribute subtype.
Instance Method Summary collapse
-
#media_subtype ⇒ Object
Obsolete: use
subtypeinstead. -
#multipart? ⇒ Boolean
:call-seq: multipart? -> false.
Instance Attribute Details
#body ⇒ Object
Returns the value of attribute body
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def body @body end |
#content_id ⇒ Object
Returns the value of attribute content_id
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def content_id @content_id end |
#description ⇒ Object
Returns the value of attribute description
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def description @description end |
#disposition ⇒ Object
Returns the value of attribute disposition
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def disposition @disposition end |
#encoding ⇒ Object
Returns the value of attribute encoding
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def encoding @encoding end |
#envelope ⇒ Object
Returns the value of attribute envelope
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def envelope @envelope end |
#extension ⇒ Object
Returns the value of attribute extension
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def extension @extension end |
#language ⇒ Object
Returns the value of attribute language
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def language @language end |
#lines ⇒ Object
Returns the value of attribute lines
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def lines @lines end |
#location ⇒ Object
Returns the value of attribute location
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def location @location end |
#md5 ⇒ Object
Returns the value of attribute md5
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def md5 @md5 end |
#media_type ⇒ Object
Returns the value of attribute media_type
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def media_type @media_type end |
#param ⇒ Object
Returns the value of attribute param
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def param @param end |
#size ⇒ Object
Returns the value of attribute size
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def size @size end |
#subtype ⇒ Object
Returns the value of attribute subtype
1076 1077 1078 |
# File 'lib/net/imap/response_data.rb', line 1076 def subtype @subtype end |
Instance Method Details
#media_subtype ⇒ Object
Obsolete: use subtype instead. Calling this will generate a warning message to stderr, then return the value of subtype.
1108 1109 1110 1111 |
# File 'lib/net/imap/response_data.rb', line 1108 def media_subtype warn("media_subtype is obsolete, use subtype instead.\n", uplevel: 1) return subtype end |
#multipart? ⇒ Boolean
:call-seq: multipart? -> false
BodyTypeMessage is not used for multipart MIME parts.
1101 1102 1103 |
# File 'lib/net/imap/response_data.rb', line 1101 def multipart? return false end |